# About

This package is for use on our S3 microsites (later versions may be implemented on WP). It's purpose is to streamline development by providing flexible reusable style components such as:

* SASS color variables
* Buttons and button groups
* Input fields including: radio labels, checkboxes, dropdowns, text inputs etc.
* Icons, fonts, and typography
* Logos for both desktop and mobile devices
* Other form elements

It's functionality is built on top of bootstrap-sass, which is a sass-powered version of [Bootstrap 3](https://getbootstrap.com/docs/3.3/getting-started/).

An interactive user interface with a full range of examples can be found at [Modify](https://modify.modernize.com). This page also has a sandbox 'qa' URL for testing changes to the package.

This design system is based on the design system sketch file that is maintained by our designers. The current version can be found here [Design System Sketch File](https://drive.google.com/drive/folders/0B183MmrG_1B7MUx1YlNEVnJjSWc), alongside a changelog, a list of archived versions of this sketch file, as well as versions that are currently in progress. If this link if not accessible, or has not been shared with you, please let someone on the engineering team know.

## Structure

* assets/
  * icons/ - icon font folder
    * modicons-basic/
    * modicons-fill/
    * modicons-stroke/
  * logos/
  * styles/
    * base/ - minimum core css files used by every page
      * animations
      * breakpoints
      * colors
      * fonts
      * index - all base components imported to this file to make it easier to import them all at once
      * reset
    * components/
      * buttons
      * images
      * index - all base components imported to this file to make it easier to import them all at once
      * inputs
      * logos
      * nav
    * icons/
      * basics
      * fille
      * index
      * stroke
    * vendor/
      * bootstrap-base - for importing minimum core bootstrap modules for all pages
      * custom-variables - for overwriting bootstraps variables with our own styles
* .editorconfig - rules for code editors based on company's code guidelines
* .sass-lint.yml - configuration for SASS/SCSS linter
* package-lock.json - lock file for package.json; makes sure that the same versions of Node modules are installed across env
* package.json - Node modules used in mod-site

## Installation

* mod-style should be added as a dependant package (in package.json).
* [bootstrap-sass](https://www.npmjs.com/package/bootstrap-sass) is also a required dependency.
  * If the site uses our mod-site dependency then bootstrap-sass is already included as a dependency of that project.
  * If mod-site is not in use you will need to manually include it in your project.
* Create a folder named `vendor` inside the `src/styles/` folder of your project.
* Inside the `vendor` folder create a file called `bootstrap-base.scss`.
* Inside this file you will import the `bootstrap-base.scss` file from this pack.

**Example: importing bootstrap base file from this package**
```css
@import '../../../node_modules/mod-style-bootstrap/assets/styles/vendor/bootstrap-base';
```

* If you need any additional bootstrap components (see below for full list of available components), you will do so in this file.

**Example: importing bootstrap components from bootstrap-sass package**
```css
@import '../../../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/code';
```

* This base file that you created will need to be pulled using a link tag in the head section of your html file.
* Your custom css for your project should be listed AFTER the bootstrap-base file.

**Example: including link tag in html file**
```html
<!DOCTYPE html>
<html lang="en">
	<head>
    <link href="/styles/vendor/bootstrap-base.css" rel="stylesheet" type="text/css" />
    <link href="/styles/home.css" rel="stylesheet" type="text/css" />
  </head>
  <body>
```

## Bootstrap Sass

Please visit [bootstrap sass](https://www.npmjs.com/package/bootstrap-sass) or [Bootstrap v3](https://getbootstrap.com/docs/3.3/getting-started/) for more information on either of these subjects.

#### styles/vendor/bootstrap-base.scss

In this package, the bootstrap-base file serves to pull in the minimum bootstrap components necessary for all pages. List of base components include:
* Core variables and mixins
  * variables
  * mixins
* Reset and dependencies
  * normalize
* Core css
  * scaffolding
  * component-animations
  * grid
  * forms
  * buttons
* Components
  * input-groups
* Components w/ JS - Note: some javascript files necessary for this to work, see [bootstrap modals](https://getbootstrap.com/docs/3.3/javascript/#modals) for more info
  * modals
* Utility classes
  * utilities
  * responsive-utilities

#### List of available bootstrap components

* Reset and dependencies
  * print
  * glyphicons
* Core css
  * type
  * code
  * tables
* Components
  * dropdowns - We use our own custom css for these elements
  * button-groups
  * navs
  * navbar
  * breadcrumbs
  * pagination
  * pager
  * labels
  * badges
  * jumbotron
  * thumbnails
  * alerts
  * progress-bars
  * media
  * list-group
  * panels
  * responsive-embed
  * wells
  * close
* Components w/ JS
  * tooltip
  * popovers
  * carousel

#### styles/vendor/custom-variables.scss

## Icons

[Icomoon](https://icomoon.io/app/#/select)


## Developing and testing locally


## License

This project is licensed under the MIT license.

Copyright (c) 2017 Modernize.
